SystemOrganization addCategory: #'Xpf-Models-Tests'!
SystemOrganization addCategory: #'Xpf-Models'!

TestCase subclass: #XpfTestCase
	instanceVariableNames: 'originalDatabase'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models-Tests'!

XpfTestCase subclass: #XpfProjectTest
	instanceVariableNames: 'testProject testUser projects users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models-Tests'!

!XpfProjectTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:27'!
setUp
	projects := XpfProject projects. XpfProject projects: Set new.
	users := XpfUser users. XpfUser users: Set new.
	testProject := XpfProject new title: 'testProject'.
	testUser := 	XpfUser new
			login: 'christopher.schuster';
			firstName: 'Christopher';
			lastName: 'Schuster';
			email: 'christopher.schuster@student.hpi.uni-potsdam.de'.! !

!XpfProjectTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:27'!
tearDown
	XpfProject projects: projects.
	XpfUser users: users.
	testProject := nil.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 2/13/2009 16:06'!
testAttributes
	| user |
	user := XpfProject new.
	self
		checkAccessor: #title on: user with: 'xpforums'.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'topa 2/16/2009 17:25'!
testHasDevelopers
	
	| developerCount userCount developer|
	
	developerCount := testProject developers size.
	userCount := XpfUser all size.
	developer := testProject attachDeveloper: testUser.
		
	self 
		should: XpfUser all size = (userCount + 1);
		should: testProject developers size = (developerCount + 1);
		should: (XpfUser all includes: developer);
		should: (testProject developers includes: developer).
	testProject detachDeveloper: developer.
	
	self 
		should: XpfUser all size = (userCount + 1);
		should: testProject developers size = developerCount;
		should: (XpfUser all includes: developer);
		shouldnt: (testProject developers includes: developer).! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:29'!
testNewAndDelete
	| project oldCount |
	
	oldCount := XpfProject all size.
	
	project := XpfProject addProject:
		(XpfProject new
			title: 'xpforums';
			yourself).
		
	self 
		should: XpfProject all size = (oldCount + 1) description: 'Project count is not valid for database.';
		should: (XpfProject all anySatisfy: [ :each | each title = 'xpforums' ]).
	
	XpfProject deleteProject: project.
	
	self should: XpfProject all size = oldCount description: 'Project count is not valid for database after deletion.'.! !

XpfTestCase subclass: #XpfTaskTest
	instanceVariableNames: 'testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models-Tests'!

!XpfTaskTest methodsFor: 'running' stamp: 'mt 2/14/2009 15:18'!
setUp
	testProject := XpfProject new title: 'testProject'; yourself.! !

!XpfTaskTest methodsFor: 'running' stamp: 'mt 2/14/2009 15:18'!
tearDown
	testProject := nil.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 14:37'!
testAttributes
	| t |
	t := XpfTask new.
	self
		checkAccessor: #title on: t with: 'SVN einrichten';
		checkAccessor: #explanation on: t with: 'SVN auf dem Server installieren und Benutzer einrichten.';
		checkAccessor: #timeEstimated on: t with: 10;
		checkAccessor: #timeActual on: t with: 12;
		checkAccessor: #userStories on: t with: (Set with: XpfUserStory new with: XpfUserStory new). ! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:53'!
testHasUserStories
	| userStory task storyCount |
	storyCount := testProject userStories size.
	task := XpfTask new.
	userStory := XpfUserStory new.
	
	self should: task userStories size = 0.
	
	testProject attachTask: task.
	task attachUserStory: userStory.
	self
		should: task userStories size = 1;
		should: testProject userStories size = (storyCount + 1);
		should: (userStory tasks includes: task).
		
	task detachUserStory: userStory.
	self
		should: task userStories size = 0;
		should: testProject userStories size = (storyCount + 1).
		
	task delete.
	userStory delete.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:26'!
testNewAndDelete
	| task oldCount |
	
	oldCount := testProject tasks size.
	
	task := testProject attachTask: (XpfTask new
			title: 'test task';
			explanation: 'this is a test task';
			yourself).
		
	self 
		should: testProject tasks size = (oldCount + 1);
		should: (testProject tasks anySatisfy: [ :each | each title = 'test task' ]).
	
	task delete.
	
	self should: testProject tasks size = oldCount.! !

!XpfTestCase class methodsFor: 'testing' stamp: 'topa 2/13/2009 14:04'!
isAbstract
 	^self name = #XpfTestCase! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 10:53'!
checkAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject"
	
	aTargetObject perform: aSelector asMutator with: anObject.
	self
		should: (aTargetObject perform: aSelector) == anObject
		! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 14:03'!
denyAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject
	 that dont behave like plain accessors.
	"
	self
		shouldnt: (aTargetObject perform: aSelector) == anObject
		! !

XpfTestCase subclass: #XpfUserStoryTest
	instanceVariableNames: 'testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models-Tests'!

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 2/14/2009 14:48'!
setUp
	testProject := XpfProject new title: 'testProject'; yourself.! !

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 2/14/2009 14:48'!
tearDown
	testProject := nil.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 14:44'!
testAttributes
	| us |
	us := XpfUserStory new.
	self
		checkAccessor: #title on: us with: 'US + Tasks verwalten';
		checkAccessor: #explanation on: us with: 'Dinge tun und Sachen machen';
		checkAccessor: #priority on: us with: 5;
		checkAccessor: #timeEstimated on: us  with: 10;
		checkAccessor: #timeActual on: us  with: 12;
		checkAccessor: #tasks on: us  with: (Set with: XpfTask new with: XpfTask new). 
		
! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:40'!
testHasTasks
	
	| userStory taskCount task|
	userStory := testProject attachUserStory: XpfUserStory new.
	taskCount := testProject tasks size.
	
	self should: userStory tasks size = 0.
	task := userStory attachTask: XpfTask new.
	
	self 
		should: userStory tasks size = 1 description: 'Task count for user story is invalid.';
		should: testProject tasks size = (taskCount + 1);
		should: 	(task userStories includes: userStory).
	userStory detachTask: task.
	
	self 
		should: userStory tasks size = 0;
		should: testProject tasks size = (taskCount + 1).
	
	userStory delete.
	task delete.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 2/14/2009 15:07'!
testNewAndDelete
	| userStory oldCount |
	oldCount := testProject userStories size.
	userStory := testProject attachUserStory: (XpfUserStory new
			title: 'User Authentication';
			explanation: 'Users should register and login to the system.';
			priority: 3;
			timeEstimated: 10;
			yourself).
	self
		should: testProject userStories size = (oldCount + 1);
		should: (testProject userStories anySatisfy: [ :each | each title = 'User Authentication' ]).
	testProject detachUserStory: userStory.
	self should: testProject userStories size = oldCount! !

XpfTestCase subclass: #XpfUserTest
	instanceVariableNames: 'testUser users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models-Tests'!

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 2/16/2009 17:17'!
login
	^ 'test.user'! !

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 2/16/2009 17:17'!
password
	^ 'TEST'! !

!XpfUserTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:23'!
setUp
	users := XpfUser users.
	XpfUser users: Set new.
	testUser := XpfUser new login: self class login; password: self class password.! !

!XpfUserTest methodsFor: 'running' stamp: 'topa 2/16/2009 17:23'!
tearDown
	XpfUser users: users.
	testUser := nil.! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/13/2009 15:12'!
testAttributes
	| user |
	user := XpfUser new.
	self
		checkAccessor: #login on: user with: 'marcel.taeumel';
		checkAccessor: #firstName on: user with: 'Marcel';
		checkAccessor: #lastName on: user with: 'Taeumel';
		checkAccessor: #email on: user with: 'marcel.taeumel@student.hpi.uni-potsdam.de'.! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/14/2009 17:42'!
testHasProjects
	
	| projectCount project globalProjectCount |
	
	projectCount := testUser projects size.
	globalProjectCount := XpfProject all size.
	project := testUser attachProject:
		(XpfProject new
			title: 'xpforums';
			yourself).
		
	self 
		should: XpfProject all size = (globalProjectCount + 1);
		should: testUser projects size = (projectCount + 1);
		should: (XpfProject all includes: project);
		should: (testUser projects includes: project).
	testUser detachProject: project.
	
	self 
		should: XpfProject all size = (globalProjectCount + 1);
		should: testUser projects size = projectCount;
		should: (XpfProject all includes: project);
		shouldnt: (testUser projects includes: project).! !

!XpfUserTest methodsFor: 'testing' stamp: 'mt 2/14/2009 16:09'!
testNewAndDelete
	| user oldCount |
	
	self shouldnt: (XpfUser all anySatisfy: [ :each | each login = 'stefanc.richter' ]).
	
	oldCount := XpfUser all size.
	
	user := XpfUser addUser: (XpfUser new
			login: 'stefanc.richter';
			firstName: 'Stefan';
			lastName: 'Richter';
			email: 'stefanc.richter@student.hpi.uni-potsdam.de';
			yourself).
		
	self 
		should: XpfUser all size = (oldCount + 1);
		should: (XpfUser all anySatisfy: [ :each | each login = 'stefanc.richter' ]).
	
	XpfUser deleteUser: user.
	
	self should: XpfUser all size = oldCount.! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:18'!
testPasswordHashing

	self 
		shouldnt: (testUser respondsTo: #password); "Write only"
		should: (testUser authenticateBy: self class password);
		shouldnt: (testUser authenticateBy: self class password , 'NOT').! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:19'!
testUserAuthenticationFail

	XpfUser addUser: testUser.
	self
		should: (XpfUser authenticate: self class login by: self class password, 'NOT') isNil;
		should: (XpfUser authenticate: self class login, 'NOT' by: self class password) isNil;
		should: (XpfUser authenticate: self class login, 'NOT' by: self class password, 'NOT') isNil.
	
	XpfUser deleteUser: testUser.! !

!XpfUserTest methodsFor: 'testing' stamp: 'topa 2/16/2009 17:20'!
testUserAuthenticationSuccess

	XpfUser addUser: testUser.
	
	self should: testUser = (XpfUser authenticate: self class login  by: self class password).
	
	XpfUser deleteUser: testUser.! !

Object subclass: #XpfEntity
	instanceVariableNames: 'id'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

!XpfEntity commentStamp: 'mt 2/12/2009 12:20' prior: 0!
I am the abstract superclass of all entities in the system. These entities could be user stories, tasks, developers, themes, ...!

!XpfEntity methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:41'!
id
	^ id! !

!XpfEntity methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:41'!
id: anObject
	id := anObject! !

XpfEntity subclass: #XpfProject
	instanceVariableNames: 'title userStories tasks developers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

XpfProject class
	instanceVariableNames: 'projects lastId'!

!XpfProject class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:34'!
addProject: aProject
	self projects add: aProject.
	aProject id: self incrementId.
	^ aProject! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:37'!
all
	^ self projects! !

!XpfProject class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:37'!
deleteProject: aProject
	self projects remove: aProject.! !

!XpfProject class methodsFor: 'private' stamp: 'topa 2/16/2009 10:36'!
incrementId
	self pvtLastId: self pvtLastId + 1.
	^ self pvtLastId! !

!XpfProject class methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:37'!
initialize
	super initialize.
	self 
		projects: Set new;
		pvtLastId: 0.! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:37'!
projects
	^ projects! !

!XpfProject class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:38'!
projects: aCollection
	projects := aCollection.! !

!XpfProject class methodsFor: 'private' stamp: 'topa 2/16/2009 10:35'!
pvtLastId
	^ lastId! !

!XpfProject class methodsFor: 'private' stamp: 'topa 2/16/2009 10:35'!
pvtLastId: anInteger
	lastId := anInteger.! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:38'!
attachDeveloper: aUser

	self developers add: aUser ifPresent: [^ aUser].
	XpfUser addUser: aUser.
	aUser attachProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
attachTask: aTask
	aTask project: self.
	^ self tasks add: aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
attachUserStory: aUserStory
	aUserStory project: self.
	^ self userStories add: aUserStory
! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:39'!
detachDeveloper: aUser
	
	self developers remove: aUser ifAbsent: [^ aUser].
	aUser detachProject: self.
	^ aUser! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:43'!
detachTask: aTask

	self tasks remove: aTask ifAbsent: [^ aTask].
	aTask project: nil.
	^ aTask! !

!XpfProject methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:44'!
detachUserStory: aUserStory

	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory project: nil.
	^ aUserStory! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
developers
	^ developers! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
developers: anObject
	developers := anObject! !

!XpfProject methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:44'!
initialize
	super initialize.
	self
		userStories: Set new;
		tasks: Set new;
		developers: Set new.
	! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
tasks
	^ tasks! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
tasks: anObject
	tasks := anObject! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:09'!
title
	^ title! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:09'!
title: anObject
	title := anObject! !

!XpfProject methodsFor: 'accessing' stamp: 'mt 2/13/2009 14:58'!
userStories
	^ userStories! !

!XpfProject methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 14:58'!
userStories: anObject
	userStories := anObject! !

XpfEntity subclass: #XpfTask
	instanceVariableNames: 'title explanation userStories timeEstimated timeActual project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

!XpfTask commentStamp: 'mt 2/12/2009 12:22' prior: 0!
I am a task in tems of Extreme Programming.!

!XpfTask methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:33'!
attachUserStory: aUserStory

	self userStories add: aUserStory ifPresent: [^ aUserStory].	
	self project attachUserStory: aUserStory.
	aUserStory attachTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'deleting' stamp: 'mt 2/14/2009 15:52'!
delete
	"Deletes this task. Detaches all connections first."
	
	self userStories do: [:us | us detachTask: self].
	self project detachTask: self.! !

!XpfTask methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:19'!
detachUserStory: aUserStory

	self userStories remove: aUserStory ifAbsent: [^ aUserStory].
	aUserStory detachTask: self.
	^ aUserStory! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
explanation
	^ explanation! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
explanation: anObject
	explanation := anObject! !

!XpfTask methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:33'!
initialize
	super initialize.
	self userStories: Set new.! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 15:42'!
project
	^ project! !

!XpfTask methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 15:42'!
project: anObject
	project := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual
	^ timeActual! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual: anObject
	timeActual := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated
	^ timeEstimated! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated: anObject
	timeEstimated := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
title
	^ title! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
title: anObject
	title := anObject! !

!XpfTask methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:10'!
userStories
	^ userStories! !

!XpfTask methodsFor: 'accessing-private' stamp: 'mt 2/13/2009 15:10'!
userStories: anObject
	userStories := anObject! !

XpfEntity subclass: #XpfUser
	instanceVariableNames: 'login firstName lastName email projects password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

XpfUser class
	instanceVariableNames: 'users'!

!XpfUser commentStamp: 'mt 2/12/2009 12:24' prior: 0!
I am a system or application user. This could be an administrator, webmaster, developer or something like that.!

!XpfUser class methodsFor: 'registration' stamp: 'topa 2/16/2009 10:21'!
addUser: aUser
	^ self users add: aUser
! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
all
	^ self users! !

!XpfUser class methodsFor: 'authentication' stamp: 'topa 2/16/2009 17:07'!
authenticate: aLogin by: aPassword
	
	^ self all 
		detect: [ :aUser| (aUser login = aLogin) and: [aUser authenticateBy: aPassword]]
		ifNone: [nil]! !

!XpfUser class methodsFor: 'registration' stamp: 'topa 2/16/2009 17:10'!
deleteUser: aUser
	^ self users remove: aUser ifAbsent: [^ aUser]
! !

!XpfUser class methodsFor: 'authentication' stamp: 'topa 2/16/2009 16:52'!
hash: aString
	^ SecureHashAlgorithm new hashMessage: aString! !

!XpfUser class methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:08'!
initialize
	super initialize.
	self users: Set new.! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:32'!
users 
	^ users! !

!XpfUser class methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:08'!
users: aCollection
	users := aCollection.! !

!XpfUser methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:30'!
attachProject: aProject

	self projects add:  aProject ifPresent: [^ aProject].
	XpfProject addProject: aProject.
	aProject attachDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'authentication' stamp: 'topa 2/16/2009 16:53'!
authenticateBy: aString
	^ self pvtPassword = (self class hash: aString)! !

!XpfUser methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:30'!
detachProject: aProject
	
	self projects remove: aProject ifAbsent: [^aProject].	
	aProject detachDeveloper: self.
	^ aProject! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
email
	^ email! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
email: anObject
	email := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
firstName
	^ firstName! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
firstName: anObject
	firstName := anObject! !

!XpfUser methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:13'!
initialize
	super initialize.
	self projects: Set new.! !

!XpfUser methodsFor: 'accessing' stamp: 'test 2/16/2009 10:30'!
lastName
	^ lastName! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
lastName: anObject
	lastName := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:31'!
login
	^ login! !

!XpfUser methodsFor: 'accessing' stamp: 'mt 2/13/2009 15:06'!
login: anObject
	login := anObject! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 16:53'!
password: aString
	password := self class hash: aString! !

!XpfUser methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:31'!
projects
	^ projects! !

!XpfUser methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 17:21'!
projects: anObject
	projects := anObject! !

!XpfUser methodsFor: 'accessing-private' stamp: 'topa 2/16/2009 16:46'!
pvtPassword
	^ password! !

XpfEntity subclass: #XpfUserStory
	instanceVariableNames: 'title priority timeEstimated tasks timeActual explanation project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Models'!

!XpfUserStory commentStamp: 'topa 2/12/2009 14:06' prior: 0!
I am a user story in terms of Extreme Programming!

!XpfUserStory methodsFor: 'attach-detach' stamp: 'test 2/16/2009 10:29'!
attachTask: aTask

	self tasks add: aTask ifPresent: [^ aTask].
	self project attachTask: aTask.
	aTask attachUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'deleting' stamp: 'topa 2/16/2009 10:06'!
delete
	"Deletes this user story from the system. Detaches all connections first.
	 TODO
	"! !

!XpfUserStory methodsFor: 'attach-detach' stamp: 'topa 2/16/2009 10:20'!
detachTask: aTask

	self tasks remove: aTask ifAbsent: [^aTask].
	aTask detachUserStory: self.
	^ aTask! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
explanation
	^ explanation! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
explanation: anObject
	explanation := anObject! !

!XpfUserStory methodsFor: 'initialization' stamp: 'topa 2/16/2009 10:06'!
initialize
	super initialize.
	self tasks: Set new.! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
priority
	^ priority! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
priority: anObject
	priority := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
project
	^ project! !

!XpfUserStory methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 15:42'!
project: anObject
	project := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
tasks
	^ tasks! !

!XpfUserStory methodsFor: 'accessing-private' stamp: 'mt 2/14/2009 14:36'!
tasks: anObject
	tasks := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
timeActual
	^ timeActual! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeActual: anObject
	timeActual := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
timeEstimated
	^ timeEstimated! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
timeEstimated: anObject
	timeEstimated := anObject! !

!XpfUserStory methodsFor: 'accessing' stamp: 'topa 2/16/2009 10:20'!
title
	^ title! !

!XpfUserStory methodsFor: 'accessing' stamp: 'mt 2/14/2009 14:36'!
title: anObject
	title := anObject! !
XpfProject initialize!
XpfUser initialize!
